# Django Websites
Django Websites is django admin like.

## Installation
```
$ pip install django_websites
```
or
```
$ pip install git+https://github.com/sasriawesome/django_websites.git#egg=django-websites
```

## Usage
Look at example .. :)
